# $Header: /home/hiro/projects/dvr2/RCS/pt1.mk,v 1.6 2012/07/20 23:11:55 hiro Exp $
#
#	== Project DVR2 ==
#
#	Makefile fragment for PT1
#
#	Copyright (c) 2011,2012 Hiro Sugawara
#

PT1-VERSION		:= 20101228-7662d0ecd74b
PT1-URL	:= http://hg.honeyplanet.jp/pt1/

ARIB-DIR	= $(CWD)/PT1-arib25
PT1-DIR		= $(CWD)/PT1-$(PT1-VERSION)

#
# PT1 driver build
#
PT1:
	$(MAKE) -f Makefile.mod -C $(PT1-DIR)/driver

PT1-INSTALL: PT1
	mkdir -p $(LINUX-INSTALL)/etc/udev/rules.d
	mkdir -p $(LINUX-INSTALL)/lib/modules/$(LINUX-VERSION)/kernel/drivers/video
	PATH=`pwd`/bin:$$PATH	\
		$(MAKE) -f Makefile.mod -C $(PT1-DIR)/driver install

PT1-CLEAN:
	[ -f $(PT1-DIR)/driver/Makefile.mod ] &&	\
		$(MAKE) -f Makefile.mod -C $(PT1-DIR)/driver clean; true

PT1-CONFIGURE:
	@cd $(PT1-DIR)/driver &&	\
		if [ ! -f Makefile.mod ]; then	\
	sed -e 's|^\([[:space:]]*make.*\) /lib|\1 $$(LINUX-ROOT)/lib|g'	\
		-e 's|`uname -r`|$$(LINUX-VERSION)|g'	\
		-e 's|^\([[:space:]]*install.*\) /lib|\1 $$(LINUX-INSTALL)/lib|g'\
		-e 's| /etc| $$(LINUX-INSTALL)/etc|g'\
			<Makefile >Makefile.mod;	\
		fi

PT1-SWEEP:
	cd $(PT1-DIR)/driver &&	\
		rm -f Makefile.mod

#
# recpt1 recording program
#
RECPT1:
	$(MAKE) -C $(PT1-DIR)/recpt1

RECPT1-CONFIGURE:
	cd $(PT1-DIR)/recpt1 &&	\
		./autogen.sh &&	\
		LDFLAGS=-L$(LINUX-INSTALL)/usr/local/lib	\
		CC="gcc -I$(LINUX-INSTALL)/usr/local/include	\
			-L$(LINUX-INSTALL)/usr/local/lib"	\
		./configure --prefix=$(LINUX-INSTALL)/usr/local	\
				--includedir=$(LINUX-ROOT)/usr/include	\
				--oldincludedir=$(LINUX-ROOT)/usr/include	\
				--enable-b25

RECPT1-INSTALL: RECPT1
	$(MAKE) -C $(PT1-DIR)/recpt1 install

RECPT1-CLEAN:
	$(MAKE) -C $(PT1-DIR)/recpt1 clean

RECPT1-SWEEP:
	cd $(PT1-DIR)/recpt1 &&	\
		rm -fr config.h config.log config.status configure autom4te.cache/	\
			Makefile

#
# arib25
#
ARIB-CONFIGURE:
ARIB-SWEEP:

ARIB:
	$(MAKE) -C $(ARIB-DIR)/arib25/src	\
		PREFIX=$(LINUX-INSTALL)/usr/local	\
		CFLAGS="-I$(LINUX-ROOT)/usr/include -O2 -g -fPIC -DUSE_BCC"	\
		LDFLAGS="-L$(LINUX-ROOT)/lib -L$(LINUX-ROOT)/usr/lib"

ARIB-INSTALL: ARIB
	PATH=`pwd`/bin:$$PATH	\
		$(MAKE) -C $(ARIB-DIR)/arib25/src	\
			PREFIX=$(LINUX-INSTALL)/usr/local	install
	mkdir -p $(LINUX-INSTALL)/usr/share/pcsc/
	cp $(ARIB-DIR)/b25_docs/smartcard_list.txt	\
		$(LINUX-INSTALL)/usr/share/pcsc/

ARIB-CLEAN:
	$(MAKE) -C $(ARIB-DIR)/arib25/src clean


#
# Clone PT1 repositories
#
PT1-DOWNLOAD: CLONE-PT1 CLONE-ARIB
CLONE-PT1:
	@id=`hg identify $(PT1-URL)` &&	\
		if [ -d *-$$id ]; then	\
			echo 'PT1 up-to-date';	\
		else	\
			hg clone $(PT1-URL) PT1-`date +%Y%m%d`-$$id;	\
		fi

CLONE-ARIB:
	hg clone $(PT1-URL) $(ARIB-DIR) -r 73

#
# Distribution
#
DIST-PATCH	+=	\
	$(PT1-DIR)/driver/pt1_pci.c	\
	$(PT1-DIR)/recpt1/recpt1.c	\
	$(ARIB-DIR)/arib25/src/Makefile	\
	$(ARIB-DIR)/arib25/src/b_cas_card.h	\
	$(ARIB-DIR)/recpt1/Makefile	\
	$(ARIB-DIR)/recpt1/decoder.h

DIST-FILES	+=	\
	$(CWD)/pt1.mk	\
	$(ARIB-DIR)/arib25/src/bcc.c
